@@ -822,15 +822,16 @@ pygvfs_async_xfer_progress_callback(GnomeVFSAsyncHandle *handle,
     py_info = pygnome_vfs_xfer_progress_info_new(info);
 
     if (data->data)
-	callback_return = PyObject_CallFunction(data->func, "NNO", py_handle, py_info, data->data);
+	callback_return = PyObject_CallFunction(data->func, "NOO", py_handle, py_info, data->data);
     else
-	callback_return = PyObject_CallFunction(data->func, "NN", py_handle, py_info);
+	callback_return = PyObject_CallFunction(data->func, "NO", py_handle, py_info);
 
       /* because the programmer may keep a reference to the
        * VFSXferProgressInfo python wrapper but we don't own the
        * VFSXferProgressInfo itself, we remove the link from the
        * python wrapper to the C structure */
     pygnome_vfs_xfer_progress_info_set(py_info, NULL);
+    Py_DECREF(py_info);
 
     if (info->phase == GNOME_VFS_XFER_PHASE_COMPLETED) {
           /* cleanup everything */
